
set.seed(20)

library(glue)
library(Seurat) 
#library(gridExtra)
#library(cowplot)
#library(msigdbr)
#library(ggforce)
#library(clustree)
#library(viridis)
#library(sctransform)
#library(limma)

### ClusterProfiler Stuff
#library(clusterProfiler)
#BiocManager::install("org.Mm.eg.db", character.only = TRUE)
#library(org.Mm.eg.db)

### Putting tidyverse last because several generically-named functions are used across libraries, but I only use e.g. select() from dplyr
library(tidyverse)

if(!dir.exists("/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/code_out/DotPlot/")){
  dir.create("/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/code_out/DotPlot/")
}

out_dir <- "/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/code_out/DotPlot/"
Round <- "Round1"




### Load the .rds file
curr_seurat_object <- read_rds(file = "/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/code_out/081_Round1_cluster/081_seurat_object.rds" )

genesForDotPlot <- c("Csf1r", "Adgre1", "Cd68", "Cd14")

DotPlot(curr_seurat_object, features = rev( genesForDotPlot ) )+ coord_flip()

ggsave(path = "/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/code_out/DotPlot/", filename = "Alexis_AllCellsDotPlot_230804.pdf", device = "pdf", units = "in", width = 6, height = 6)



Idents(curr_seurat_object) <- "genotype"

genes_for_FeaturePlot <- "Cd68"

for(i in genes_for_FeaturePlot){
  print(glue("Start ", i," for all cells"))
  ### Make the feature plots for all the cells together using "curr_seurat_object"
  print(FeaturePlot(curr_seurat_object, features = i, cols = c("lightgrey", "blue"), order = TRUE, pt.size=1.25, label = F))
  ### To save plot, repeat the command below.
  pdf(glue(out_dir,Round,"Clusters_FeaturePlot_AllCellsTogether_",i,".pdf"), width = 8, height = 8)
  print(FeaturePlot(curr_seurat_object, features = i, cols = c("lightgrey", "blue"), order = TRUE, pt.size=1.25, label = F))
  dev.off()
  
  ### Make the same plot, but with split.by="Sample". There will be no legend, but the legend in the previous graphs will be applicable.
  print(FeaturePlot(curr_seurat_object, features = i, cols = c("lightgrey", "blue"), order = TRUE, pt.size=1.25, label = F, split.by="genotype", ncol=2))
  ### To save plot, repeat the command below.
  pdf(glue(out_dir,Round,"Clusters_FeaturePlot_AllCellsSplitByGenotype_",i,".pdf"), width = 16, height = 8)
  print(FeaturePlot(curr_seurat_object, features = i, cols = c("lightgrey", "blue"), order = TRUE, pt.size=1.25, label = F, split.by="genotype", ncol=2))
  dev.off()
}

### Now subset just one Cre sample into "plot_seurat_object" and repeat the above lines.  
for(j in unique(Idents(curr_seurat_object))){
  plot_seurat_object <- subset(curr_seurat_object, idents = j)
  for(i in genes_for_FeaturePlot){
    print(glue("Start ", i, " for ",j))
    #    colnames(plot_seurat_object@meta.data)[which(colnames(plot_seurat_object@meta.data) == glue(i,"1"))] <- i
    print(
      FeaturePlot(plot_seurat_object, features = i, cols = c("lightgrey", "blue"), order = TRUE, pt.size=1.25, label = F)
    )
    ### To save plots
    pdf(glue(out_dir,Round,"Clusters_FeaturePlot_",i,"_",j,".pdf"), width = 8, height = 8)
    print(FeaturePlot(plot_seurat_object, features = i, cols = c("lightgrey", "blue"), order = TRUE, pt.size=1.25, label = F))
    dev.off()
    
  }
  #print(VlnPlot(curr_seurat_object, features = i, pt.size=0.1, split.by = "Sample", split.plot = TRUE))
}



### Now subset to just the macrophage clusters and repeat with the Lyve1+ gene expression signature.
Idents(curr_seurat_object) <- "Cluster"
use_seurat_object     <- subset(curr_seurat_object, Cluster %in% c(1,3,7,9))

#genesForDotPlot <- c("Lyz2", "Plac8", "Cd74", "H2-Ab1", "H2-Aa", "Mrc1", "Apoe", "Ccl7", "Fabp5", "C1qa", "Ccl12", "Folr2", "Aif1", "Mafb", "Tgfb1", "Ccr2", "Marcks", "Malat1", "Mt1", "Zeb2", "Csf1r", "Adgre1", "Cd68", "Cd14") 
genesForDotPlot <- c("Lyz2", "Plac8", "Cd74", "H2-Ab1", "H2-Aa", "Mrc1", "Apoe", "Ccl7", "Fabp5", "C1qa", "Ccl12", "Folr2", "Aif1", "Mafb", "Tgfb1", "Ccr2", "Marcks", "Malat1", "Mt1", "Zeb2")

DotPlot(use_seurat_object, features = rev( genesForDotPlot ) )+ coord_flip()

ggsave(path = "/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/code_out/DotPlot/", filename = "Alexis_MphageDotPlot_230804.pdf", device = "pdf", units = "in", width = 6, height = 6)

