knitr::opts_knit$set(root.dir = '/panfs/jay/groups/20/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/')


### Clear all the objects in memory
rm(list = ls(all.names = TRUE))

RUNALLSTEPS <- FALSE


# Set R working directory
proj_dir <- "/home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502"


### !!! Specify Round of clustering, etc. here !!! ___ Allow for specifying via command line or sourced document in future versions.
#Round <- "Round0" ; res_to_use <- 0.6 ; clusters_to_use <- c(0:1,3:6,8:16)
Round <- "Round1" ; res_to_use <- 0.6 ; clusters_to_use <- c(1,3,7,9)
#Round <- "Round2" ; res_to_use <- 0.6 ; clusters_to_use <- c(0:10)



## ---- Load packages, include=FALSE--------------------------------------------
# ---------------------------------------------------------------------
# Load R packages
# ---------------------------------------------------------------------
print(Sys.time()); print("")
print("Loading packages"); 

set.seed(20)

options(
  rlang_backtrace_on_error = "full",
  error = rlang::entrace,
  menu.graphics = FALSE
)

library(glue)
library(Seurat) 
library(gridExtra)
library(cowplot)
library(msigdbr)
library(ggforce)
library(clustree)
library(viridis)
#library(sctransform)
library(limma)

### ClusterProfiler Stuff
library(clusterProfiler)
#BiocManager::install("org.Mm.eg.db", character.only = TRUE)
library(org.Mm.eg.db)

### Putting tidyverse last because several generically-named functions are used across libraries, but I only use e.g. select() from dplyr
library(tidyverse)




MH <- read.gmt(gmtfile = "/panfs/jay/groups/20/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/input/mh.all.v2023.1.Mm.symbols.gmt")

M2 <- read.gmt(gmtfile = "/panfs/jay/groups/20/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/input/m2.all.v2023.1.Mm.symbols.gmt")

M5 <- read.gmt(gmtfile = "/panfs/jay/groups/20/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/input/m5.all.v2023.1.Mm.symbols.gmt")

MHM2M5 <- rbind(MH, M2, M5)


### Quick code to get the GSEA plot for GOMF_GLYCOSAMINOGLYCAN_BINDING as requested by Alexis 

#nPerm = 1000
pvalueCutoff = 1
minGSSize = 10
maxGSSize = 500

curr_seurat_object <- read_rds(file = glue("{proj_dir}/code_out/{prefix}{Round}_cluster/{prefix}seurat_object.rds")) 

out_dir <- glue("{proj_dir}/CodeOutput/{Round}Clusters/GSEA_output/")
if(!dir.exists({out_dir})) {dir.create(glue("{out_dir}"), recursive = TRUE)}


### Read in the relevant GSEA results for Round1 Cluster 7:
for(i in 7){
  geneList <-        read.table(file = glue("{proj_dir}/CodeOutput/{Round}Clusters/GSEA_input/{Round}Clusters_Cluster{i}_{ident.1}V{ident.2}_minpct{min.pct.rnk}_log2fc{logfc.threshold.rnk}_230101.rnk"))[,2]
  names(geneList) <- read.table(file = glue("{proj_dir}/CodeOutput/{Round}Clusters/GSEA_input/{Round}Clusters_Cluster{i}_{ident.1}V{ident.2}_minpct{min.pct.rnk}_log2fc{logfc.threshold.rnk}_230101.rnk"))[,1]
  
  print(Sys.time()); print(glue("Starting GSEA for Cluster {i} for MHM2M5"))
  print(glue("Proportion of non-0s for i = {i}: {round(sum(geneList != 0)/length(geneList),2)}"))
  enrich <- GSEA(geneList, 
                 minGSSize = minGSSize,
                 maxGSSize = maxGSSize,
                 TERM2GENE = MHM2M5,
                 pvalueCutoff = pvalueCutoff,
                 pAdjustMethod = "BH")
}

CustomGeneSetID <- which(enrich[,"Description"] == "GOMF_GLYCOSAMINOGLYCAN_BINDING")

gseaplot(enrich, by = "all", title = enrich$Description[CustomGeneSetID], geneSetID = CustomGeneSetID)
ggsave(plot = last_plot(), filename = "test_GLYCOSAM.pdf", path = out_dir, device = "pdf")

