#!/bin/Rscript env


### Modifying Todd's workflows. See this one for this section: https://github.umn.edu/knut0297org/farrarm_todd_citeseq_nilotinib_pdl1_20210109/blob/663ae278f1b2aa0b0b36c762f61a31fec193e272/code/001_r_packages.R

### Start an interactive session on a node and load some modules in bash before running the R code.
### To run from command line, do this in the terminal from agate:
if(FALSE){
### !!! Since this sequencing run had 3 separate captures (C0, C1, C2), we are using a separate working dir for each. 
### The cellranger stuff may have been one level up at some point, but should be moved into the capture-specific dir.
cd /home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/

### Everything you need should be in a conda environment loadable with the following commands. Details on creating the .venv are at the bottom of /home/lmnp/bmcc/envs/scRNAseq.take3.pip-requires
  module load python3/3.9.3_anaconda2021.11_mamba
  source activate /home/lmnp/bmcc/envs/scRNAseq.take3.venv

}

### To run via Open On Demand, start OOD with this in the Custom Environment box:
if(FALSE){
  cd /home/schwertf/shared/disaster_recovery/bmcc/braedan_AE_scrnaseq_220502/
    
  module load python3/3.9.3_anaconda2021.11_mamba
  source activate /home/lmnp/bmcc/envs/scRNAseq.take3.venv
  
  module load udunits/2.2.27.6_gcc7.2.0 # Needed for Seurat and/or clusterProfiler
  module load geos/3.7.1 # Required for loading Seurat in R
  
}


options(menu.graphics = FALSE)
original_options <- options(); str(original_options)


# The best way to update a package, is to simply re-run install.packages()


# ---------------------------------------------------------------------
# Package library paths
# ---------------------------------------------------------------------
# Show current package locations
.libPaths()
# [1] "/panfs/jay/groups/3/lmnp/bmcc/envs/scRNAseq.take3.venv/lib/R/library"


# In bash:
# echo $R_LIBS

### Trying installs for 4.0.3_openblas
# ---------------------------------------------------------------------
# CRAN
# ---------------------------------------------------------------------

# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load udunits/2.2.27.6_gcc7.2.0
# Needed for Seurat and/or clusterProfiler
install.packages("units", configure.args = c(units = "--with-udunits2-lib=/panfs/roc/msisoft/udunits/2.2.27.6_gcc7.2.0/lib --with-udunits2-include=/panfs/roc/msisoft/udunits/2.2.27.6_gcc7.2.0/include"))
### OK

# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load libgit2/1.1.0
install.packages("devtools")
### OK


# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load magick/7.0.8-23
install.packages("magick")
install.packages("summarytools")
### OK

# The V8 R packages needs this bash variable set before starting R. This will download a static libv8 library
# to be used during compile. "ggforce" depends on V8
# export DOWNLOAD_STATIC_LIBV8=1
install.packages("ggforce")


# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load libpng/1.6.34
install.packages("png")

# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load libicu4c/58.2
install.packages("igraph")

# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load gsl/2.3
install.packages("gsl")


# This package needs certain libraries available in bash $LD_LIBRARY_PATH variable before staring R. Run the following before starting R.
# module load gdal/2.3.2
# export PKG_CONFIG_PATH=/panfs/roc/msisoft/gdal/2.3.2/lib/pkgconfig:$PKG_CONFIG_PATH
# module load proj/4.9.3
# module load geos/3.7.1
install.packages("sf")



install.packages("optparse")
install.packages("GSA")
install.packages("dbscan")
install.packages("GGally")
install.packages("glue")
install.packages("scales")
install.packages("openxlsx")
install.packages("BiocManager")
install.packages("tidyverse")
install.packages("RColorBrewer")
install.packages("statmod")
install.packages("matrixStats")
install.packages("cowplot")
install.packages("gridExtra")
install.packages("ggupset")
install.packages("ggrepel")
install.packages("skimr")
install.packages("waldo")
install.packages("snakecase")
install.packages("metap")
install.packages("msigdbr")
install.packages("HGNChelper")
install.packages("viridis")
install.packages("ggfittext")
install.packages("DescTools")
install.packages("lme4")
install.packages("mice")
install.packages("doSNOW")
install.packages("amap")
install.packages("clusteval")
install.packages("caret")
install.packages("gghighlight")




# ---------------------------------------------------------------------
# Github
# ---------------------------------------------------------------------



remotes::install_github("renozao/NMF@d02eba9")



# This module needs to be loaded in bash before starting R:
# module load hdf5/1.8.13
# To install a certain branch or commit or tag, append it to the repo name, after an @:
remotes::install_github("hhoeflin/hdf5r@5c9074f")


# This module needs to be loaded in bash before starting R:
# module load libsodium/1.0.18
# To install a certain branch or commit or tag, append it to the repo name, after an @:
remotes::install_github("YosefLab/VISION@6e15d78")
# remotes::install_github("hrbrmstr/gzmem")


# scDC: Single cell differential composition analysis
# https://sydneybiox.github.io/scDC/index.html
# https://github.com/taiyunkim/scClustBench
remotes::install_github("taiyunkim/scClustBench@a254e55")
remotes::install_github("SydneyBioX/scDC@e2a1d8c")


# For Monocle
remotes::install_github("satijalab/seurat-wrappers@156e392")
remotes::install_github("cole-trapnell-lab/leidenbase@8c52ebc")
remotes::install_github("cole-trapnell-lab/monocle3@4c01d89")



# ---------------------------------------------------------------------
# Seurat installed version
# ---------------------------------------------------------------------
# Release version 4.0.0
remotes::install_github("satijalab/seurat@81e6361")


# NOTE ABOUT SEURAT:
# Error: Please install the metap package to use FindConservedMarkers.
# This can be accomplished with the following commands:
# ----------------------------------------
# install.packages('BiocManager')
# BiocManager::install('multtest')
# install.packages('metap')
# ----------------------------------------






# ---------------------------------------------------------------------
# Bioconductor
# ---------------------------------------------------------------------
  
### BMM 230314: Many of these are for more complicated analyses that Todd was running. Commenting out lines that are likely unneeded or have issues installing.

# BiocManager::install("genefilter")
  ### Failed due to "installation of package ‘sf’ had non-zero exit status" 
  ### BiocManager::install("edgeR")
  BiocManager::install("biomaRt")
  BiocManager::install("DESeq2")
#  BiocManager::install("apeglm")
#  BiocManager::install("vsn")
#  BiocManager::install("BiocParallel")
  BiocManager::install("GSEABase")
  # Install R "units" package first (needed for clusterProfiler)
  BiocManager::install("clusterProfiler")
#  BiocManager::install("DOSE")
  BiocManager::install("org.Hs.eg.db")
  BiocManager::install("org.Mm.eg.db")
#  BiocManager::install("GSVA")
#  BiocManager::install("multtest")
#  BiocManager::install("scRepertoire")
  BiocManager::install("scran")
  # For Monocle
#  BiocManager::install(c('BiocGenerics', 'DelayedArray', 'DelayedMatrixStats',
#                         'limma', 'S4Vectors', 'SingleCellExperiment',
#                         'SummarizedExperiment', 'batchelor', 'Matrix.utils'))
  
#  BiocManager::install("slingshot")
#  BiocManager::install("tradeSeq")
#  BiocManager::install("scater")
#  BiocManager::install("SingleR")
#  BiocManager::install("celldex")


# ---------------------------------------------------------------------
# Archived packages removed from CRAN
# ---------------------------------------------------------------------


# remotes::install_url("https://cran.r-project.org/src/contrib/Archive/tcR/tcR_2.3.2.tar.gz")



# ---------------------------------------------------------------------
# Load R libraries
# ---------------------------------------------------------------------



library(tidyverse)
#library(devtools)
#library(openxlsx)
#library(clusterProfiler)
#library(DOSE)
library(org.Hs.eg.db)
library(org.Mm.eg.db)
#library(NMF)
library(RColorBrewer)
library(DESeq2)
library(edgeR)
library(biomaRt)
library(glue)
#library(statmod)
#library(vsn)
#library(apeglm)
#library(genefilter)
#library(BiocParallel)
library(BiocManager)
library(GSEABase)
library(Seurat)
#library(matrixStats)
#library(gridExtra)
library(cowplot)
#library(hdf5r)
library(ggupset)
library(ggrepel)
#library(skimr)
#library(waldo)
#library(snakecase)
#library(multtest)
#library(metap)
library(msigdbr)
#library(VISION)
#library(HGNChelper)
library(viridis)
library(ggfittext)
#library(tcR)
#library(scRepertoire)
library(gghighlight)


# ---------------------------------------------------------------------
# Load custom R functions
# ---------------------------------------------------------------------
### Testing without Todd's custom functions. 

#source("code/002_r_functions.R")
